<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00001001DocumentoPropostaFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function limparAnexoDaProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOC
                   SET NMARQUIVO     = NULL,
                       DSCAMINHOARQ  = NULL,
                       DSTIPO        = NULL,
                       VRTAMANHO     = NULL,
                       IDDOCALTERADO = 'S'
                 WHERE INSTR(:NRSEQORCADOC, '_' || TO_CHAR(NRSEQORCADOC) || '_') > 0
                   AND NRORG        = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getDocumentoProposta(array $params) {
        $sql = "SELECT NRSEQORCADOC,
                       TXMODELOORCADOC,
                       NMARQUIVO,
                       DSCAMINHOARQ,
                       DSTIPO,
                       VRTAMANHO
                  FROM FCT_ORCAMENTODOC
                 WHERE INSTR(:NRSEQORCADOC, '_' || TO_CHAR(NRSEQORCADOC) || '_') > 0
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function atualizarCaminhoDocumentoProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOC
                   SET DSCAMINHOARQ = :DSCAMINHOARQ,
                       DTULTATU     = SYSDATE,
                       CDOPERULTATU = :CDOPERULTATU,
                       NRORGULTATU  = :NRORGULTATU
                 WHERE INSTR(:NRSEQORCADOC, '_' || TO_CHAR(NRSEQORCADOC) || '_') > 0
                   AND NRORG        = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Retorna o docuemnto de uma determinada proposta em um situação
     * especificada
    **/
    public function getDocumentoPropostaPorSituacao($idSituacao, array $params) {
        $sql = "SELECT LISTAGG(IDSITUACAOORCAMENTO, ', ') WITHIN GROUP (ORDER BY IDSITUACAOORCAMENTO) AS IDSITUACAOORCAMENTO
                FROM FCT_ORCAMENTODOC
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                    AND NRORG        = :NRORG
                    AND (IDSITUACAOORCAMENTO IN('$idSituacao')
                        OR (IDSITUACAOORCAMENTO IS NULL AND '". str_replace("','", "", $idSituacao) . "' IS NULL))";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Altera o docuemnto para um novo
    **/
    public function alterarDocumentoProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOC
               SET NMARQUIVO       = :NMARQUIVO,
                   DSCAMINHOARQ    = :DSCAMINHOARQ,
                   DSTIPO          = :DSTIPO,
                   VRTAMANHO       = :VRTAMANHO,
                   VRTAMANHOLOGO   = :VRTAMANHOLOGO,
                   CDOPERULTATU    = :OPERADOR,
                   NRORGULTATU     = :NRORG,
                   DTULTATU        = SYSDATE,
                   IDDOCALTERADO   = 'S'
                WHERE INSTR(:NRSEQORCADOC, '_' || TO_CHAR(NRSEQORCADOC) || '_') > 0
                   AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function atualizarTamanhoLogotipoDocumentos(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOC
                   SET VRTAMANHOLOGO = :VRTAMANHOLOGO,
                       NRORGULTATU   = :NRORGULTATU,
                       CDOPERULTATU  = :CDOPERULTATU,
                       DTULTATU      = SYSDATE
                 WHERE INSTR(:NRSEQORCADOC, '_' || TO_CHAR(NRSEQORCADOC) || '_') > 0
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getQuantidadeDocumentosPorPropostaESituacao(array $params) {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM FCT_ORCAMENTODOC
                 WHERE NRSEQORCAMENTO      = :NRSEQORCAMENTO
                   AND IDSITUACAOORCAMENTO = :IDSITUACAOORCAMENTO
                   AND NRORG               = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function excluirSituacoesDocumentoProposta(array $params) {
        $sql = "DELETE FROM FCT_ORCAMENTODOCSITU
                 WHERE NRSEQORCADOC = :NRSEQORCADOC";

        $this->connection->executeStatement($sql, $params);
    }
    
    public function inserirSituacoesDocumentoProposta(array $params) {
        $sql = "INSERT INTO FCT_ORCAMENTODOCSITU (
                    NRORCAMENTODOCSITU,  NRSEQORCADOC,   IDSITUACAOORCAMENTO,
                    IDATIVO,             NRORG,          DTINCLUSAO,
                    NRORGINCLUSAO,       CDOPERINCLUSAO
                )
                VALUES (
                    :NRORCAMENTODOCSITU,  :NRSEQORCADOC,   :IDSITUACAOORCAMENTO,
                    :IDATIVO,             :NRORG,          SYSDATE,
                    :NRORGINCLUSAO,       :CDOPERINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function getDocumentoPropostaIdioma(array $params) {
        $sql = "SELECT DOCID.NRSEQORCADOC,
                       ORDOC.NRSEQMODDOCFCT,
                       DOCID.NMARQUIVO,
                       DOCID.DSCAMINHOARQ,
                       DOCID.DSTIPO,
                       DOCID.VRTAMANHO,
                       DOCID.CDIDIOM
                  FROM FCT_ORCAMENTODOCIDIOMA DOCID
                  JOIN FCT_ORCAMENTODOC ORDOC
                    ON DOCID.NRSEQORCADOC = ORDOC.NRSEQORCADOC
                 WHERE DOCID.NRORCAMENTODOCIDIOMA = :NRORCAMENTODOCIDIOMA
                   AND DOCID.NRORG                = :NRORG";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
    
    public function limparAnexoDocumentoPropostaIdioma(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOCIDIOMA
                   SET NMARQUIVO     = NULL,
                       DSCAMINHOARQ  = NULL,
                       DSTIPO        = NULL,
                       VRTAMANHO     = NULL
                 WHERE NRORCAMENTODOCIDIOMA = :NRORCAMENTODOCIDIOMA
                   AND NRORG                = :NRORG";
        
        $this->connection->executeStatement($sql, $params);
    }
    
    public function getModeloDocumentoIdioma(array $params) {
        $sql = "SELECT NMARQUIVO,
                       DSCAMINHOARQ,
                       DSTIPO,
                       VRTAMANHO
                  FROM FCT_MODELODOCIDIOMA
                 WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT
                   AND CDIDIOM        = :CDIDIOM";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function atualizarDocumentoPropostaIdioma(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOCIDIOMA
                   SET NMARQUIVO     = :NMARQUIVO,
                       DSCAMINHOARQ  = :DSCAMINHOARQ,
                       DSTIPO        = :DSTIPO,
                       VRTAMANHO     = :VRTAMANHO,
                       CDOPERULTATU  = :CDOPERULTATU,
                       DTULTATU      = SYSDATE
                 WHERE NRORCAMENTODOCIDIOMA = :NRORCAMENTODOCIDIOMA
                   AND NRORG                = :NRORG";
        
        $this->connection->executeStatement($sql, $params);
    }

    public function atualizarAnexoDocumentoProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOC
                   SET NMARQUIVO    = :NMARQUIVO,
                       VRTAMANHO    = :VRTAMANHO,
                       DSTIPO       = :DSTIPO,
                       DSCAMINHOARQ = :DSCAMINHOARQ
                 WHERE NRSEQORCADOC = :NRSEQORCADOC";

        $this->connection->executeStatement($sql, $params);
    }
}

?>