<?php

namespace Teknisa\SM\Service;

use Doctrine\ORM\EntityManager;
use Teknisa\SM\Factory\IntegracaoHcmfactory;
use Teknisa\Libs\Util\Environment;

class IntegracaoHcmService {
    
    protected $hcmFactory;
    protected $environment;
    protected $entityManager;
    protected $connection;
    
    public function __construct(Environment $environment, EntityManager $entityManager, IntegracaoHcmFactory $IntegracaoHcmFactory){
        $this->environment   = $environment;
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
        $this->hcmFactory    = $IntegracaoHcmFactory;
    }
    
    /**
     * Efetua as configurações necessárias para o usuário do CRM
     * salvar a proposta
     * @params array $rows dados da proposta recebidos do CRM
    **/
    // public function integracaoHcm($rows){
    //     try{
    //         $nrorg = $rows["requisitante"]["nrorg"];
    //         $entityManagerConnection = $this->connectionCustom->updateVpdConnection($nrorg);
            
    //         if ($entityManagerConnection !== false) {
    //             $this->entityManager = $entityManagerConnection;
    //         }
            
    //         $this->connection = $this->entityManager->getConnection();
    //         $this->newCode = new NewCode($this->connection, "NOVO_CODIGO_SC");
    //         $this->integracaoHcmfactory = new IntegracaoHcmfactory($this->entityManager);
            
    //         $retorno = $this->buscaLancamentosDeCalculo($rows, $nrorg);
            
    //         return $retorno;
    //     } catch(\Exception $e) {
    //         throw $e;
    //     }
    // }
    
    /**
     * Salva a proposta com os dados recebidos do crm
     * @params array $rows dados da proposta recebidos do CRM
    **/
    // public function buscaLancamentosDeCalculo($rows, $nrorg){
    //     try{
    //         $this->connection->beginTransaction();
            
    //         $dtmescompetenc = $rows[""]["DTMESCOMPETENC"];
    //         $nrtipomoviment = $rows[""]["NRTIPOMOVIMENT"];
    //         $nrcpfpessoa = $rows[""]["NRCPFPESSOA"];
            
    //         $informacoesHoraExtra = $this->retornaLancamentosDeCalculo($nrorg, $dtmescompetenc, $nrtipomoviment, $nrcpfpessoa);

    //         $this->connection->commit();
    //         return $informacoesHoraExtra;
            
    //     } catch(\Exception $e) {
    //         $this->connection->rollback();
    //         throw $e;
    //     }    
    // }
    
    /**
     * Retorna os dados da proposta presentes no modelo
     * @params $nrorg nr organização
     * @params $nrSeqOrcamentoModelo nr do modelo
    **/
    // public function retornaLancamentosDeCalculo($nrorg, $dtmescompetenc, $nrtipomoviment, $nrcpfpessoa){
    //     $paramsHoraExtra = array(
    //         "DTMESCOMPETENC" => $dtmescompetenc,
    //         "NRTIPOMOVIMENT" => $nrtipomoviment,
    //         "NRCPFPESSOA" => $nrcpfpessoa,
    //         "NRORG"             => $nrorg
    //     );
        
    //     $dataSet = $this->integracaoHcmfactory->retornaLancamentosDeCalculo($paramsHoraExtra);
    //     return $dataSet;
    // }

    public function integracaoHcm($params, $massa = 'N', $escala = 'N')
    {   
        $paramsVal = array(
            "NRSEQCONTRATO" => $params["NRSEQCONTRATO"]
        );

        $validaIntegracaoHCM = $this->hcmFactory->verificarUtilizaIntegracao($paramsVal);
       

        if ($validaIntegracaoHCM == 'S'){
            $token = '';
            $paramGeral = $this->hcmFactory->getParamsGeral();
            $access = $this->checkAccess($paramGeral[0]['DSURLHCM'], $paramGeral[0]['DSTOKENHCM'], $paramGeral[0]['DSSECRETHCM']);
        
            if($access == 'Denied'){
                $this->connection->beginTransaction();
                $token = $this->requestToken($paramGeral[0]['DSURLHCM'], $paramGeral[0]['DSIDHCM'], $paramGeral[0]['DSSECRETHCM']);
                $params = array(
                    "TOKEN" => $token
                );
                $this->hcmFactory->updateToken($params);
                $this->connection->commit();
            } else {
                $token = $paramGeral[0]['DSTOKENHCM'];
            }

            if ($escala == 'N') {
                return $this->setEstrutura($params, $paramGeral[0]['DSURLHCM'], $token, $paramGeral[0]['DSSECRETHCM']);
            }
            else {
                return $this->getEscalaTrab($paramGeral[0]['DSURLHCM'], $token, $paramGeral[0]['DSSECRETHCM']);
            }
        }
        else  {
          if (($massa == 'N') && ($params["IDAPROVACAO"] == 'S')){
            return 'OK';  
          }
          else {
            return 'Contrato não está habilitado para integração com o HCM. Favor verificar o campo "Realiza integração com HCM?" na tela "Lançamento de Contrato"';
          }
        }
    }

    public function checkAccess($uri, $token, $secret)
    {
        $uri_produ = $uri.'/checkAccess';
        $clientData = array(
            "TOKEN" => $token,
            "CLIENT_SECRET" => $secret,
        );
        $header[] = 'Content-Type: application/json';
        $header[] = 'Content-Length: ' . strlen(json_encode($clientData));
        $result = $this->connectionWebService($header, $uri_produ, $clientData);
        if ($result['messages'][0]['message'] == "Authorized") {
            return "Authorized";
        } else {
            return "Denied";
        }
    }

    public function requestToken ($uri, $id, $secret) 
    {
        $uri_produ = $uri.'/requestToken';
        $clientData = array(
            "CLIENT_ID" => $id,
            "CLIENT_SECRET"=> $secret,
        );
        $header[] = 'Content-Type: application/json';
        $header[] = 'Content-Length: ' . strlen(json_encode($clientData));
        $result = $this->connectionWebService($header, $uri_produ, $clientData);
        return $result['dataset']['token'][0];
    }


    /**
     * Função responsável por criar estrutura
     *
     * @param Request\Row $request  No request são esperados os campos:
     * Informações obrigatórias:
     * - NRTIPOESTRUTURA : Número do tipo de Estrutura conforme descrição abaixo:
     *      1- EMPRESA
     *      2- FILIAL
     *      3- DEPARTAMENTO
     *      4- SETOR
     *      5- CENTRO CUSTO
     *      6- EQUIPE
     *      7- TOMADOR DE SERVICOS
     *      8- REGIÃO
     *      9- PROJETO
     *      10- SINDICATO
     *      11- OBRA
     *      12- PRODUTO
     *      13- PLANO DE SAÚDE
     *      14- ESCOLA
     *      25- LABORATÓRIO
     *      26- FORNECEDOR
     * - DTINIVIGENCIA : Data de início de vigência da respectiva estrutura (caso não seja informada, ficará com a data 01/01/2000).
     * - NMFANTASIA: Nome fantasia do cliente.
     * - NMRAZSOCESTRUT: Razão social do cliente.
     * - CDCNPJESTRUT: Nº do CNPJ do Cliente.
     * - NRCEPENDERECO: CEP do endereço da estrutura.
     * - NMPAIS: Nome do país do endereço da estrutura.
     * - SGESTADO: Sigla do estado do endereço da estrutura.
     * - NMMUNICIPIO: Nome do município da estrutura.
     * - NMBAIRROENDERECO: Nome do bairro do endereço da estrutura.
     * - CDLOGRADOURO: Descrição do tipo de logradouro do endereço da estrutura (rua, avenida,…).
     * - DSENDERECO: Descrição do endereço da estrutura.
     * - NRIMOVELENDERECO: número da estrutura do endereço da estrutura.
     * - DSCOMPLEENDERECO: Descrição do complemento do endereço da estrutura.
     * - DSREFERENCIAENDE: Descrição da referência do endereço da estrutura.
     *
     *  Informações não obrigatórias:
     * - IDTIPOEMPR: Tipo de empresa conforme descrição abaixo:
     *      1 – Microempresa
     *      2 – Empresa de Pequeno Porte
     *      3 – Empresa/Órgão
     *      4 – Microempreendedor Individual
     *      5 – Empregador Doméstico
     *      6 – Empregador Rural
     * - IDOPTSIMPLES: Indica se a empresa é optante pelo simples (opções “S” ou “N”).
     * - IDPARTICIPAT: Indica se a empresa participa do “Programa de Alimentação do Trabalhador”.
     * - NRTIPOTRIBUT: tipo de tributação da empresa conforme opções abaixo:
     *      1 – Lucro Real
     *      2 – Lucro Presumido
     *      3 – Simples Nacional
     * - NRCLASSTRIBUT: código da classificação tributária (conforme tabela CLASSTRIBUT).
     * - VRALIQDESON: valor percentual da alíquota de desoneração.
     * - NRCALENDARIO: número do calendário da estrutura.
     * - CDCNAE: Código do CNAE da empresa.
     * - CDFPAS: Código do FPAS.
     * - CDTERCEIRO: código de terceiros.
     * - VRFAP: Valor do Fator Acidentário de Prevenção (FAP) da empresa.
     * - CDCEIESTRUT: CEI da empresa.
     * - NRCAGED: Código CAGED.
     * - CDEMPRCAIXA: Código de FGTS na Caixa Econômica Federal.
     * - CDFEDERALESTRUT: Código do registro federal (exemplo: código ANS do plano de saúde).
     * - NRPROPRIEMPR: CPF do proprietário.
     * - NRPARCRESPINF: CPF do responsável informal.
     * - NRPARCENTISIN: CPF do responsável legal.
     * - CDINTESTRUTEXPFIL: Código de exportação (Filial)
     * - CDINTESTRUTEXP: Código de exportação (Centro de Custo)
     *  Obs: Para o psoto de trabalho, não é obrigatório passar CNPJ
     * 
     * @param Response $response    A resposta será no formato de um Dataset (Array)
     * Array (
     *  [dataset] = Array (
     *      [estrutura] = Array (
     *          true
     *      )
     *  )
     * )
     */
    
     public function setEstrutura($params, $uri, $token, $secret)
    {
        $tipoEstrut = null;

        $dataParam = array(
            "NRSEQCONTRATO" => $params['NRSEQCONTRATO']
        );

        $dados = $this->hcmFactory->getParametrosContrato($dataParam);

        if (count($dados) > 0 ){

            if ($dados[0]['IDINTEGRACAOHCM'] == 'S'){

                $integraEscala = $dados[0]['IDINTEGRAESCALAHCM'];
               
                if ($dados[0]['TPESTRUTINTEGRAHCM'] == 'T'){ // 7 - Tomador
                    $tipoEstrut = 'T';
                    $nrEstrutura = 7;
                    $contrato = $this->hcmFactory->getDadosContratoTomador($dataParam);
                }
                else { // 69 - Posto de Trabalho

                    $valida = $this->ValidaDadosPostoTrab($params['NRSEQCONTRATO']);
                    $tipoEstrut = 'P';
                    $nrEstrutura = 69;

                    if ($valida == 'OK') {
                        $contrato = $this->hcmFactory->getDadosContratoPosto($dataParam);
                    }
                    else {
                        $contrato = array();
                    }
                }
            }
            else {

                $contrato = array();
            }
        }

        if (count($contrato) > 0 ){

            foreach ($contrato as $cont){
                $uri_produ = $uri."/setEstrutura";
                $header = array(
                    "OAuth-Token: $token",
                    "OAuth-SecretId: $secret"
                );
                $header[] = 'Content-Type: application/json';
                if ($tipoEstrut == 'T') {
                    $data = array(
                        'requestType' => 'Row',
                            'row' => array(
                                "NRTIPOESTRUTURA"   => $nrEstrutura,
                                "DTINIVIGENCIA"     => $cont['DTINICIOCONTRATO'],
                                "NMFANTASIA"        => $cont['NMPRINCIPALPARC'],
                                "NMRAZSOCESTRUT"    => $cont['NMPRINCIPALPARC'],
                                "CDCNPJESTRUT"      => $cont['NRINSCRICAOPARC'] ,
                                "NRCEPENDERECO"     => $cont['NRCEPENDERECO'],
                                "NMPAIS"            => $cont['NMPAIS'],
                                "SGESTADO"          => $cont['SGESTADO'],
                                "NMMUNICIPIO"       => $cont['NMMUNICIPIO'],
                                "NMBAIRROENDERECO"  => $cont['NMBAIRROENDERECO'],
                                "CDLOGRADOURO"      => ($cont['CDLOGRADOURO'] == NULL) ? 0 : $cont['CDLOGRADOURO'],
                                "DSENDERECO"        => ($cont['DSENDERECO'] == NULL) ? 'Não há' : $cont['DSENDERECO'],
                                "NRIMOVELENDERECO"  => ($cont['NRIMOVELENDERECO'] == NULL) ? 0 : $cont['NRIMOVELENDERECO'],
                                "DSCOMPLEENDERECO"  => ($cont['DSCOMPLEENDERECO'] == NULL) ? 'Não há' : $cont['DSCOMPLEENDERECO'],
                                "DSREFERENCIAENDE"  => ($cont['DSREFERENCIAENDE'] == NULL) ? 'Não há' : $cont['DSREFERENCIAENDE'],
                                "IDOPTSIMPLES"      => 'N'
                        ));
                }
                else {
                    $data = array(
                        'requestType' => 'Row',
                            'row' => array(
                                "NRTIPOESTRUTURA"   => $nrEstrutura,
                                "DTINIVIGENCIA"     => $cont['DTINICIOCONTRATO'],
                                "NMFANTASIA"        => $cont['NMPRINCIPALPARC'],
                                "NMRAZSOCESTRUT"    => $cont['NMPRINCIPALPARC'],
                                "CDCNPJESTRUT"      => $cont['NRINSCRICAOPARC'] ,
                                "CDINTESTRUTEXPFIL" => $cont['CDFILIAL'],
                                "CDINTESTRUTEXP"    => $cont['CDCENTCUST'],
                                "NRCEPENDERECO"     => $cont['NRCEPENDERECO'],
                                "NMPAIS"            => $cont['NMPAIS'],
                                "SGESTADO"          => $cont['SGESTADO'],
                                "NMMUNICIPIO"       => $cont['NMMUNICIPIO'],
                                "NMBAIRROENDERECO"  => $cont['NMBAIRROENDERECO'],
                                "CDLOGRADOURO"      => ($cont['CDLOGRADOURO'] == NULL) ? 0 : $cont['CDLOGRADOURO'],
                                "DSENDERECO"        => ($cont['DSENDERECO'] == NULL) ? 'Não há' : $cont['DSENDERECO'],
                                "NRIMOVELENDERECO"  => ($cont['NRIMOVELENDERECO'] == NULL) ? 0 : $cont['NRIMOVELENDERECO'],
                                "DSCOMPLEENDERECO"  => ($cont['DSCOMPLEENDERECO'] == NULL) ? 'Não há' : $cont['DSCOMPLEENDERECO'],
                                "DSREFERENCIAENDE"  => ($cont['DSREFERENCIAENDE'] == NULL) ? 'Não há' : $cont['DSREFERENCIAENDE'],
                                "IDOPTSIMPLES"      => 'N'
                        ));
    
                }

                $estrutura = $this->connectionWebService($header, $uri_produ, $data);

                if ($tipoEstrut == 'P'){
                    $estrutM = $cont['NRESTRUTURAM'];
                    $filial = $cont['CDFILIAL'];
                    $centrCust = $cont['CDCENTCUST'];
                }
                else {
                    $estrutM = null;
                    $filial = null;
                    $centrCust = null;
                }

                if((isset($estrutura['dataset']['setEstrutura'][0]) && $estrutura['dataset']['setEstrutura'][0]) 
                || (isset($estrutura['messages'][0]['message']) && $estrutura['messages'][0]['message'] == 'Já existe estrutura para o mesmo tipo de estrutura e CNPJ')
                || (isset($estrutura['messages'][0]['message']) && $estrutura['messages'][0]['message'] == 'Já existe estrutura para o mesmo tipo de estrutura e códigos de filial e centro de custo')) {
                return $this->setQuadroVagas($uri, $token, $secret, $nrEstrutura, $cont['NRINSCRICAOPARC'], $params['NRSEQCONTRATO'],  $cont['DTINICIOCONTRATO'], $tipoEstrut, $integraEscala, $estrutM, $filial, $centrCust);
                } else {
                    return $estrutura['messages'][0]['message'];
                }
            }
        }
        else {

            if ($tipoEstrut == 'T') {
                return 'Não foi encontrado o endereço principal do parceiro de negócio.';
            }
            else if ($tipoEstrut == 'P'){
                return $valida;
            }
            else {
                return 'Contrato nao está habilitado para integração. Favor verificar o parâmetro "Realiza Integração HCM" na página "Dados do Contrato".';
            }
        }
    }

    /**
     * Função responsável por criar um quadro de vagas
     *
     * @param Request\Row $request  No request são esperados os campos:
     * Informações obrigatórias:
     * - CDCNPJESTRUT: CNPJ da estrutura
     * - NRTIPOESTRUTURA : Número do tipo de Estrutura conforme descrição abaixo:
     *      1- EMPRESA
     *      2- FILIAL
     *      3- DEPARTAMENTO
     *      4- SETOR
     *      5- CENTRO CUSTO
     *      6- EQUIPE
     *      7- TOMADOR DE SERVICOS
     *      8- REGIÃO
     *      9- PROJETO
     *      10- SINDICATO
     *      11- OBRA
     *      12- PRODUTO
     *      13- PLANO DE SAÚDE
     *      14- ESCOLA
     *      25- LABORATÓRIO
     *      26- FORNECEDOR
     * - CDOCUPACAO: Código de integração da ocupação
     * - QTDLIMITE: Quantidade limite do quadro de vagas
     * - DTINIVALIDADE: Data de início de validade do quadro de vagas no formato DD/MM/YYYY
     * Informações não obrigatórias:
     * - DTFIMVALIDADE: Data fim de validade do quadro de vagas no formato DD/MM/YYYY
     * - CDPROPOSTA: Código da proposta
     * - NRESCALATRABM: Número da Escala de Trabalho
     * - CDFILIAL: Código de exportação (Filial)
     * - CDCENTROCUSTO: Código de exportação (Centro de Custo)
     *  Obs: Para o psoto de trabalho, não é obrigatório passar CNPJ
     * 
     * @param Response $response    A resposta será no formato de um Dataset (Array)
     * Array (
     *  [dataset] = Array (
     *      [quadro] = Array (
     *          true
     *      )
     *  )
     * )
     */
    public function setQuadroVagas($uri, $token, $secret, $estrutura, $cnpj, $nrseqcontrato, $dtfinal, $tipoEstrut, $integraEscala, $estrutM, $filial, $centrCust)
    {
        $param = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "TIPOESTRUT" => $tipoEstrut,
            "NRESTRUTURAM" => $estrutM
        );
        
        $itensContrato = $this->hcmFactory->getItensContrato($param);
        $uri_produ = $uri."/setQuadroVagas";
        $header = array(
            "OAuth-Token: $token",
            "OAuth-SecretId: $secret"
        );
        $header[] = 'Content-Type: application/json';
        foreach ($itensContrato as $value) {
            
            if ($integraEscala == 'S'){
                $escala = $value['NRESCALATRABALHOHCM'];
            }
            else {
                $escala = null;
            }

            if ($tipoEstrut == 'T') {
                $data = array(
                    'requestType' => 'Row',
                    'row' => array(
                        "CDCNPJESTRUT"      => $cnpj,
                        "NRTIPOESTRUTURA"   => $estrutura,
                        "CDOCUPACAO"        => $value['CDSERVORCA'],
                        "QTDLIMITE"         => $value['QTITEMCONTRATO'],
                        "DTINIVALIDADE"     => $dtfinal,
                        "CDPROPOSTA"        => $value['NRSEQCONTRATO'],
                        "NRESCALATRABM"     => $escala
                    )
                );
            }
            else {
                $data = array(
                    'requestType' => 'Row',
                    'row' => array(
                        "CDCNPJESTRUT"      => $cnpj,
                        "CDFILIAL"          => $filial,
                        "CDCENTROCUSTO"     => $centrCust,
                        "NRTIPOESTRUTURA"   => $estrutura,
                        "CDOCUPACAO"        => $value['CDSERVORCA'],
                        "QTDLIMITE"         => $value['QTITEMCONTRATO'],
                        "DTINIVALIDADE"     => $dtfinal,
                        "CDPROPOSTA"        => $value['NRSEQCONTRATO'],
                        "NRESCALATRABM"     => $escala
                    )
                );
            }
            $quadro = $this->connectionWebService($header, $uri_produ, $data);

            if((isset($quadro['dataset']['setQuadroVagas'][0]) && $quadro['dataset']['setQuadroVagas'][0]) 
            || (isset($quadro['messages'][0]['message']) && $quadro['messages'][0]['message'] == 'Já existe um quadro com mesma estrutura e ocupação do novo registro, com proposta igual ou com períodos de validade intercedentes')) {
                return 'OK';
            } else {
                return $quadro['messages'][0]['message'];
            }
        }
    }

    public function connectionWebService($header, $uri_produ, $data) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
        curl_setopt($ch, CURLOPT_URL, $uri_produ);
        curl_setopt($ch, CURLOPT_POST, count($data));
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
        $result = curl_exec($ch);
        curl_close($ch);
        return json_decode($result, true);
    }
   

    public function integracaoHcmMassa ($rows){
        try{
            $retorno = null;
            $retornoNOK = false;
            $arrayRetorno = array();

            foreach ($rows as $row) {
                if ($row['IDSITUACAOCONTRATO'] == 'A') {

                    $retorno = $this->integracaoHcm($row, 'S');

                    if ($retorno != 'OK') {
                        $retornoNOK = true;

                        $retorno = 'Operação bloqueada! '.$retorno;

                    }
                  
                }
                else {
                    $retorno = 'Operação bloqueada! Só é permitido atualizar quadro de vagas de contratos aprovados.';
                    $retornoNOK = true;
                }

                $arrayRetorno[] = array("NRCONTRATOFCT" => $row['NRCONTRATOFCT'],
                                        "NMPARCNEGOCIO" => $row['NMPRINCIPALPARC'],
                                        "RESULTADO"     => $retorno);

            }

            if ($retornoNOK == false){
                return 'OK';
            } 
            else {
                return $arrayRetorno;
            }

        } catch(\Exception $e) {
            return $e->getMessage();
        }

    }

    public function carregaDadosEscalaintegracaoHCMItens($row){
        try{
            $cdoperador = $this->environment->getCdOperador();
            $nrorg      = $this->environment->getNrOrg();

            $idIntegracaoHCM  = $row["IDINTEGRACAOHCM"];
            $integraEscalaHCM = $row["IDINTEGRAESCALAHCM"];

            if (($idIntegracaoHCM == 'S') && ($integraEscalaHCM == 'S')) {
              $escalas = $this->integracaoHcm($row, 'N', 'S');

              if (isset($escalas['dataset']['getEscalaTrab'])) {

                /*  Deleta escalas anteriores */
                $params = array(
                    "NRORG" => $nrorg
                );

                $this->hcmFactory->deleteEscalasHCMTemp($params);

                /* insere escalas novas */
                foreach($escalas['dataset']['getEscalaTrab'] as $escala){
                    
                    $params = array(
                        "NRESCALATRABM"   => $escala["NRESCALATRABM"],
                        "NMESCALATRABH"   => $escala["NMESCALATRABH"],
                        "NRNMESCALATRABM" => $escala["NRNMESCALATRABM"],
                        "NRORG"           => $nrorg,
                        "CDOPERINCLUSAO"  => $cdoperador
                    );

                    $this->hcmFactory->insertEscalasHCMTemp($params);
                }
              }

              return 'OK';
            }
        
        } catch(\Exception $e) {
            return $e->getMessage();
        }
    }

    public function getEscalaTrab($uri, $token, $secret)
    {
            $uri_produ = $uri."/getEscalaTrab";
            $header = array(
                "OAuth-Token: $token",
                "OAuth-SecretId: $secret"
            );
            $header[] = 'Content-Type: application/json';
            $data = array(
                'requestType' => 'Row',
                    'row' => array());

           return $this->connectionWebService($header, $uri_produ, $data);
       
    }

    public function ValidaDadosPostoTrab($nrseqcontrato) {

        $param = array(
            "NRSEQCONTRATO" => $nrseqcontrato
        );
        
        $validacoes = $this->hcmFactory->validaContratoPosto($param);

        $erros = 0;
        $itensErro1 = ''; 
        $estruturasErro2 = '';
        $estruturasErro3 = '';

        foreach($validacoes as $valida){
            /* 1 - Será verificado se todos os itens estão vinculados à um local de atendimento. */
            if ($valida['ERRO1'] == 'S') {
                $erros = $erros+1;
                $itensErro1 = $itensErro1.'  - '.$valida['NMITEMCONTRATO'].' <br>';
            }

            /* 2 - Será verificado se todos os locais de atendimento vinculados foram convertidos em filial. */
            if ($valida['ERRO2'] == 'S') {
                $erros = $erros+1;
                $estruturasErro2 = $estruturasErro2.'  - '.$valida['NMESTRUTURAM'].' <br>';
            }
    
            /* 3 - Será verificado se todos os locais de atendimento possuem Centro de Custo Vinculado. */
            if ($valida['ERRO3'] == 'S') {
                $erros = $erros+1;
                $estruturasErro3 = $estruturasErro3.'  - '.$valida['NMESTRUTURAM'].' <br>';
            }
        }

        if ($erros == 0){
            return 'OK';
        }
        else {
            $retornoErro1 = '';
            $retornoErro2 = '';
            $retornoErro3 = '';
            
            if ($itensErro1 != ''){
                $retornoErro1 = 'Itens que não possuem vínculo com Local de Atendimento:  <br><br>'.$itensErro1.'<br>';
            }

            if ($estruturasErro2 != ''){
                $retornoErro2 = 'Locais de Atendimento não convertidos em Filial:  <br><br>'.$estruturasErro2.'<br>';
            }

            if ($estruturasErro3 != ''){
                $retornoErro3 = 'Locais de Atendimento sem centro de custo informado:  <br><br>'.$estruturasErro3.'<br>';
            }

            $retorno = 'Existem parametrizações pendentes para a realização da integração, sendo: <br><br>'. $retornoErro1.$retornoErro2.$retornoErro3;

            return $retorno;
        }

    }
}

